<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:as="http://www.oasis-open.org/committees/cam" xmlns:w2e="http://thisSheet" xmlns:xsd="http://www.w3.org/2001/XMLSchema" 
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:camed="http://jcam.org.uk/editor" 
    exclude-result-prefixes="xsd w2e xs camed">
    <!-- CAM kit utility program -->
    <!-- Provided "as is" License: Creative Commons - http://creativecommons.org/licenses/by-sa/3.0/
        Authors: David RR Webber, May, 2008 -->
    <!--
        Purpose  : Parse CAM annotation (anno) internal format XML and output Hints file from any rules embedded inside the anno syntax.
        Takes inputs of existing annotation file.  Allows exchange of hint rules across different CAM templates using the same content tags.
        Original : 06/05/2008
        Initials : drrw
        This ver     :  * see version variable below *
        CAM ver    : 1.1 
        Description : Part of a set of tools to ease alignment of XSD based validations and documentation
        and CAM templates. Exports hint values for use with CAM 2 examples generator. 
        Updated  - Inits - Change
        06/05/08   drrw   Initial release
        
    -->
    <xsl:output method="xml" indent="yes" omit-xml-declaration="yes"/>
    <xsl:output name="hintsXML" method="xml" indent="yes" omit-xml-declaration="yes" />
    
    <xsl:param name="outputName">hints-export.xml</xsl:param>
 
    <xsl:variable name="version">1.01</xsl:variable>
  
    <xsl:template match="/"> 

        <xsl:if test="count(//as:Extension/camed:annotation)=0">
            <xsl:message terminate="yes">Input file is not valid CAM anno internal format (.anno)</xsl:message>
        </xsl:if>
       
        <html>
            <body>
                <h3>CAM Hints Export Utility</h3>
                <h4>Version <xsl:value-of select="$version"/></h4>
                <p><b>For output to <xsl:value-of select="$outputName"/></b></p>
                
                <h4>PARAMETERS:</h4>
                <table>
                    <tr><td>Output to: </td><td><xsl:value-of select="$outputName"/></td></tr>
                </table>
                
                <xsl:message>Processing output to <xsl:value-of select="$outputName"/></xsl:message>
                
                <ul>
                    <xsl:for-each select="//as:Extension/camed:annotation"><xsl:if test="count(camed:documentation[@type='Value']) &gt; 0"><li>Hint: [<xsl:value-of select="@item"/>]</li></xsl:if></xsl:for-each>
                </ul>
                <xsl:message>Finished - <xsl:value-of select="current-dateTime()"/></xsl:message>
                <p>Finished - <xsl:value-of select="current-dateTime()"/></p>
            </body>
        </html>
        <xsl:result-document exclude-result-prefixes="w2e as" format="hintsXML" indent="yes" href="{$outputName}" omit-xml-declaration="no" >
            <xsl:comment>
                Autogenerated by CAM Hints Export XSLT (version <xsl:value-of select="$version"/>)
                
                Output to: <xsl:value-of select="$outputName"/> <xsl:value-of select="'&#xD; &#xD;' "/>
                
            </xsl:comment>
            <as:HINTS xmlns:as="http://www.oasis-open.org/committees/cam" CAMlevel="1" version="{$version}">
                <as:Header>
                    <as:Description>Autogenerated by CAM Hints Export XSLT (version <xsl:value-of select="$version"/>)</as:Description>
                    <as:Owner>To be Completed</as:Owner>
                    <as:Version>0.1</as:Version>
                    <as:DateTime><xsl:value-of select="current-dateTime()"/></as:DateTime>
                </as:Header>
                <as:HintDetails> 
                    <xsl:apply-templates select="//as:Extension/camed:annotation"/>
                </as:HintDetails>
             </as:HINTS>
        </xsl:result-document>
    </xsl:template>
    
   <xsl:template match="camed:annotation">
       <xsl:variable name="values" select="camed:documentation[@type='Value']"/>
       <xsl:variable name="xpath" select="@item"/>
       <xsl:if test="count($values) &gt; 0">
           <xsl:variable name="Key" select="camed:documentation[@type='Key']"/>  
           <xsl:variable name="Parent" select="camed:documentation[@type='Parent']"/> 
           <xsl:variable name="Like" select="camed:documentation[@type='Like']"/>
           <xsl:variable name="With" select="camed:documentation[@type='With']"/>
           <xsl:choose>
               <xsl:when test="count($Like) &gt; 0">
                   <xsl:element name="as:Hint">
                       <xsl:attribute name="like" select="$Like"/>
                       <xsl:if test="string-length($With) &gt; 0">
                           <xsl:attribute name="with" select="$With"/>
                       </xsl:if>
                       <xsl:variable name="value" select="camed:documentation[@type='Value']"></xsl:variable>
                       <xsl:variable name="values" select="tokenize($value,'\|')"/>
                       <xsl:for-each select="$values">
                           <xsl:if test="string-length(.) &gt;0">
                           <xsl:element name="as:Value"><xsl:value-of select="."/></xsl:element>
                           </xsl:if>
                       </xsl:for-each>
                   </xsl:element>
               </xsl:when>
               <xsl:when test="count($Key) &gt; 0">
                   <xsl:element name="as:Hint">
                       <xsl:attribute name="Key" select="$Key"/>
                       <xsl:if test="string-length($Parent) &gt; 0">
                           <xsl:attribute name="parent" select="$Parent"/>
                       </xsl:if>
                       <xsl:variable name="value" select="camed:documentation[@type='Value']"></xsl:variable>
                       <xsl:variable name="values" select="tokenize($value,'\|')"/>
                       <xsl:for-each select="$values">
                           <xsl:if test="string-length(.) &gt;0">
                           <xsl:element name="as:Value"><xsl:value-of select="."/></xsl:element>
                          </xsl:if>
                       </xsl:for-each>
                   </xsl:element>
               </xsl:when>
               <xsl:otherwise>
                   <xsl:variable name="path_items" select="tokenize($xpath,'/')"/>
                   <xsl:variable name="items" select="count($path_items)"/>
                   <xsl:element name="as:Hint">
                       <xsl:attribute name="Key" select="$path_items[$items]"/>
                       <xsl:if test="$items &gt; 3">
                           <xsl:attribute name="parent" select="$path_items[$items - 1]"/>
                       </xsl:if>
                       <xsl:variable name="value" select="camed:documentation[@type='Value']"></xsl:variable>
                       <xsl:variable name="values" select="tokenize($value,'\|')"/>
                       <xsl:for-each select="$values">
                           <xsl:if test="string-length(.) &gt;0">
                               <xsl:element name="as:Value"><xsl:value-of select="."/></xsl:element>
                           </xsl:if>
                       </xsl:for-each>
                   </xsl:element>
                   
               </xsl:otherwise>
           </xsl:choose>
       </xsl:if>
    </xsl:template>
    
</xsl:stylesheet>
<!-- Stylus Studio meta-information - (c) 2004-2007. Progress Software Corporation. All rights reserved.

<metaInformation>
	<scenarios/>
	<MapperMetaTag>
		<MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no"/>
		<MapperBlockPosition></MapperBlockPosition>
		<TemplateContext></TemplateContext>
		<MapperFilter side="source"></MapperFilter>
	</MapperMetaTag>
</metaInformation>
-->