<?xml version="1.0" encoding="UTF-8"?> 
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsd="http://www.w3.org/2001/XMLSchema"
    xmlns:as="http://www.oasis-open.org/committees/cam" xmlns:camed="http://jcam.org.uk/editor"
    xmlns:lexs="http://usdoj.gov/leisp/lexs/3.1" 
    xmlns:w="http://niem.gov/niem/wantlist/1" 
    exclude-result-prefixes="xs xsd" version="2.0">

    <!-- Provided "as is" License: Creative Commons - http://creativecommons.org/licenses/by-sa/3.0/ 

Author: David RR Webber, June, 2008 -->

    <!-- 

Purpose : Take a CAM template format in CXF format and remove all items with exclude() rules.
Original : 06/14/2008 
Initials : drrw 
CAM ver : 1.1 
Description : Part of a set of tools to ease alignment of XSD based validations and documentation 
and CAM templates. 
How to use :  Source input is CAM template in CXF format. The excludeTree, excludeElement and excludeAttribute rules contained in it are used to determine removal of items.
Updated - Inits - Change 
06/14/08 drrw Initial release.
06/19/08 drrw Correct use of @context check
06/21/08 drrw Add @condition check as well
07/31/08 drrw Copy as:Namespaces section
-->
    <xsl:param name="compressMode">comment</xsl:param><!-- remove | comment -->
    
    <xsl:output indent="yes"/>
    
    <xsl:variable name="version">1.02</xsl:variable>
 
    <xsl:template match="/">
    <xsl:message>Starting processing, version <xsl:value-of select="$version"/></xsl:message>
    <xsl:element name="as:CAM">
        <xsl:copy-of select="as:CAM/namespace::*"/>
        <xsl:copy-of select="as:CAM/attribute::*"/>
        <xsl:copy-of select="as:CAM/as:Header"/>
        <xsl:copy-of select="as:CAM/as:Namespaces"/>
        <xsl:element name="as:AssemblyStructure">
            <xsl:element name="as:Structure">
                <xsl:copy-of select="as:CAM/as:AssemblyStructure/as:Structure/attribute::*"/>
                <xsl:copy-of select="as:CAM/as:AssemblyStructure/as:Structure/as:parameters"/>
                <xsl:apply-templates select="as:CAM/as:AssemblyStructure/as:Structure/as:Element/."/>
            </xsl:element>
        </xsl:element>
        <xsl:copy-of select="as:CAM/as:include"/>
        <xsl:copy-of select="as:CAM/as:Extension"/>
    </xsl:element>
     <xsl:message>Finished</xsl:message>   
    </xsl:template>
    
    <xsl:template match="as:Element">
        <xsl:choose>  
            <xsl:when test="count(as:Rule/as:constraint[@action='excludeTree()' and(not(@context)) and(not(@condition))]) &gt; 0"><xsl:if test="$compressMode='comment'"><xsl:comment>removed element [<xsl:value-of select="@name"/>] path [<xsl:value-of select="@name"/>]<xsl:value-of select="'&#xD;'"/></xsl:comment></xsl:if></xsl:when>    
            <xsl:when test="count(as:Rule/as:constraint[@action='excludeElement()' and(not(@context)) and(not(@condition))]) &gt; 0"><xsl:if test="$compressMode='comment'"><xsl:comment>removed element [<xsl:value-of select="@name"/>] path [<xsl:value-of select="@name"/>]<xsl:value-of select="'&#xD;' "/></xsl:comment></xsl:if></xsl:when>
        <xsl:otherwise>
            <xsl:element name="as:Element">
                <xsl:copy-of select="attribute::*"/>
                <xsl:copy-of select="camed:annotation"/>
                <xsl:copy-of select="as:Rule"/>
                <xsl:apply-templates select="as:Attribute"/>
                <xsl:apply-templates select="as:Element"/>
            </xsl:element>
        </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="as:Attribute">
        <xsl:choose>  
            <xsl:when test="count(as:Rule/as:constraint[@action='excludeAttribute()' and(not(@context)) and(not(@condition))]) &gt; 0"><xsl:if test="$compressMode='comment'"><xsl:comment>removed attribute [<xsl:value-of select="@name"/>] path [<xsl:value-of select="@name"/>]<xsl:value-of select="'&#xD;' "/></xsl:comment></xsl:if></xsl:when>    
            <xsl:otherwise><xsl:copy-of select="."></xsl:copy-of></xsl:otherwise>
       </xsl:choose>
    </xsl:template>
        
</xsl:stylesheet>
