<?xml version="1.0"?>
<xsl:stylesheet version="2.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:as="http://www.oasis-open.org/committees/cam" 
	xmlns:camed="http://jcam.org.uk/editor" 
	xmlns:w2e="http://thisSheet" 
	xmlns:xsd="http://www.w3.org/2001/XMLSchema" 
	xmlns:xs="http://www.w3.org/2001/XMLSchema" 
	xmlns:w_niem="http://niem.gov/niem/wantlist/1"
	exclude-result-prefixes="xsd xs w2e w_niem" >
	<!-- CAM kit utility program -->
	<!-- Provided "as is" License: Creative Commons - http://creativecommons.org/licenses/by-sa/3.0/
		Authors: David RR Webber, 2009 -->
	<!--
		Purpose  : Grab CAMeditor XSD schema XSLT input stream into a file to allow diagnosis / testing in external tools.
		Original : 06/25/2009
		Initials : drrw
		CAM ver    : 1.1 
		Description : Part of a set of tools to ease alignment of XSD based validations and documentation
		and CAM templates. Generates an XSD instance.
		
		NOTE: Puts output XSD into:
		
		C:\Program Files\uk.org.jcam\CAMed_1.66\CAMed\workspace\CAMEditor
		
		Updated  - Inits - Change
		06/25/09   drrw   Initial release
	-->

	<xsl:output method="xml" indent="yes" omit-xml-declaration="yes"/>
	<xsl:output name="XSD" method="xml" indent="no" omit-xml-declaration="yes" />
	
	<xsl:param name="elementName"></xsl:param>
	<xsl:param name="complexTypeName"></xsl:param>
	<xsl:param name="logLevel">1</xsl:param>
	<xsl:param name="CAM">true</xsl:param>
	<xsl:param name="CAMmode">diagnostic, rules, anno</xsl:param>
	<xsl:param name="annoFile">default.anno</xsl:param>
	<xsl:param name="annoExclude">xsd:|xlink:|xpil:|axal:|nxnl:|xnl:|xal:</xsl:param>
	<xsl:param name="annoMode">inline</xsl:param>
	<xsl:param name="annoContent">text</xsl:param><!-- values: text or all -->
	<xsl:param name="wantlist"></xsl:param>
	<!-- xsl:param name="anonymousNS"></xsl:param -->

	<!-- values are: structure, rules, inline, anno, reference, diagnostics -->
	
	<xsl:variable name="allRootLevelTypeDefinitions">allRootLevelTypeDefinitions</xsl:variable>
	
	<xsl:variable name="wantlistFile">
		<xsl:choose>
			<xsl:when test="contains($wantlist,'/')"><xsl:value-of select="if( starts-with($wantlist,'file:')) then translate($wantlist,'\','/') else concat('file:///',translate($wantlist,'\','/'))"/></xsl:when>
			<xsl:when test="contains($wantlist,'\')"><xsl:value-of select="if( starts-with($wantlist,'file:')) then translate($wantlist,'\','/') else concat('file:///',translate($wantlist,'\','/'))"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="$wantlist"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="annoExclTokens" select="tokenize($annoExclude,'\|')"></xsl:variable>
	<xsl:variable name="defaultNS" select="if(count(/xsd:schema) &gt; 0) then namespace-uri-for-prefix('',/xsd:schema) else '*ERROR*'"/>
	
	<xsl:variable name="ns-prefix">as:ns-prefix</xsl:variable>
	
	<xsl:variable name="version">1.00</xsl:variable>
	<xsl:variable name="excludeAttrRules" select="if (string-length($wantlistFile) &gt; 0) then document($wantlistFile)//Attribute[@w_niem:isXclude='1'] else ''"/>
	
	<xsl:variable name="rootVersion" select="/xs:schema/@version"/>
	
	<xsl:variable name="entireXSDcollection" select="/"/>

	<xsl:template match="/">
		<xsl:if test="$defaultNS='*ERROR*'"><xsl:message terminate="yes">ERROR: Input file is not a valid XSD schema!</xsl:message></xsl:if>
		<xsl:variable name="element-to-process">
			<xsl:choose>
				<xsl:when test="string-length($elementName) = 0">
					<xsl:value-of select="xsd:schema/xsd:element[1]/@name"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$elementName"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
<xsl:variable name="results">
<as:CAM CAMlevel="1" version="1.0">
	<!-- xsl:if test="$anonymousNS &gt; ' '">
		<xsl:namespace name="{$anonymousNS}"><xsl:value-of select="$defaultNS"/></xsl:namespace>
	</xsl:if -->
	<!-- xsl:comment>[<xsl:value-of select="$defaultNS"/>]</xsl:comment -->
  <as:Header>
  	<as:Description>Generated for <xsl:value-of select="concat(if ($elementName='*') then $allRootLevelTypeDefinitions else if($complexTypeName) then $complexTypeName else $element-to-process,' ')"/> by XSD grabber <xsl:value-of select="$version"/></as:Description>
   <as:Owner>To be Completed</as:Owner>
   <as:Version><xsl:value-of select="if(string-length($rootVersion) &gt; 0) then $rootVersion else '0.1'"/></as:Version>
   <as:DateTime><xsl:value-of select="current-dateTime()"/></as:DateTime>
  </as:Header>
  <as:AssemblyStructure>
  	<as:Structure taxonomy="XML" ID="{concat(if($elementName='*') then $allRootLevelTypeDefinitions else if($complexTypeName) then $complexTypeName else $element-to-process,'')}">
		<dummy>%nothing%</dummy>
	</as:Structure>
  </as:AssemblyStructure>
	<as:BusinessUseContext>
		<as:Rules>
			<as:default>
				<as:context/>
			</as:default>
		</as:Rules>
	</as:BusinessUseContext>
</as:CAM>
</xsl:variable>
		
		<xsl:for-each select="$results/*">
			<xsl:copy>
				<xsl:for-each select=".//namespace::*">
					<xsl:if test="not(name()='w2e')">
						<xsl:namespace name="{name()}" select="."/>
					</xsl:if>
				</xsl:for-each>
				<xsl:copy-of select="@*|node()"/>
			</xsl:copy>
		</xsl:for-each>
		
		<xsl:variable name="xsdFile">
			<xsl:choose>
				<xsl:when test="contains($annoFile,'.anno')">
					<xsl:value-of select="concat(substring-before($annoFile,'.anno'),'.xsd')"></xsl:value-of>
				</xsl:when>
				<xsl:otherwise>file:///C:\temp\grabber\xsd-grabber-result.xsd</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:result-document exclude-result-prefixes="w2e as w_niem" format="XSD" indent="no" href="{$xsdFile}">
			<xsl:copy-of select="$entireXSDcollection"/>
		</xsl:result-document>
		
	</xsl:template>
	
</xsl:stylesheet>
